"""SCIP (Code Intelligence Protocol) support for Cicada.

This module provides functionality to read and convert SCIP index files
generated by language indexers like scip-python into Cicada's universal
index format.

SCIP is a language-agnostic protocol created by Sourcegraph for code intelligence.
Learn more: https://github.com/sourcegraph/scip
"""

from cicada.languages.scip.converter import SCIPConverter
from cicada.languages.scip.reader import SCIPReader

__all__ = ["SCIPReader", "SCIPConverter"]
